@@ -48,8 +48,8 @@ def get_markdown_parsers():
     )
 
     parsers[f"mistune ({mistune.__version__})"] = mistune.html
-    parsers[f"mistune (slow)"] = mistune.create_markdown(escape=False)
-    parsers[f"mistune (fast)"] = mistune.create_markdown(escape=False, plugins=["speedup"])
+    parsers["mistune (slow)"] = mistune.create_markdown(escape=False)
+    parsers["mistune (fast)"] = mistune.create_markdown(escape=False, plugins=["speedup"])
     parsers["mistune (full)"] = mistune.create_markdown(
         escape=False,
         plugins=[
