@@ -10,17 +10,21 @@ class TestTocHook(BaseTestCase):
         md = create_markdown(escape=False)
         add_toc_hook(md)
         html, state = md.parse(text)
-        result = html + render_toc_ul(state.env['toc_items'])
+        result = html + render_toc_ul(state.env["toc_items"])
         return result
 
     def test_customize_heading_id_func(self):
         def heading_id(token, i):
-            return 't-' + str(i + 1)
+            return "t-" + str(i + 1)
 
         md = create_markdown(escape=False)
         add_toc_hook(md, heading_id=heading_id)
-        html = md('# h1')
+        html = md("# h1")
         self.assertEqual(html, '<h1 id="t-1">h1</h1>\n')
 
+    def test_render_empty_toc(self):
+        self.assertEqual(render_toc_ul([]), "")
+        self.assertEqual(render_toc_ul(filter(lambda _: False, [])), "")
 
-TestTocHook.load_fixtures('hook_toc.txt')
+
+TestTocHook.load_fixtures("hook_toc.txt")
