@@ -8,5 +8,5 @@ class TestSyntax(BaseTestCase):
         self.assertEqual(normalize_html(result), normalize_html(html))
 
 
-TestSyntax.load_fixtures('fix-commonmark.txt')
-TestSyntax.load_fixtures('diff-commonmark.txt')
+TestSyntax.load_fixtures("fix-commonmark.txt")
+TestSyntax.load_fixtures("diff-commonmark.txt")
